local Henhouse = ...

local myMonument = {
    DataType = "BUILDING",
    Id = _PastryPrefix .. "_HENHOUSE",
    Name = _PastryPrefix .. "_HENHOUSE_NAME",
    Description = _PastryPrefix .. "_HENHOUSE_DESC",
    BuildingType = "GENERAL"
}

if (foundation.getGameVersion == nil or version.cmp(foundation.getGameVersion(), "1.6") < 0) then
    Henhouse:log("Hello World: game version anterior to 1.6")
    myMonument.BuildingPartSetList = {
		{
			Name = _PastryPrefix .. "_HENHOUSE_NAME",
                	BuildingPartList = { _PastryPrefix .. "_HENHOUSE_PART" }
                }
    } 
    _vjrTagBehaviorWork = "WORK_BEHAVIOR"
    _CoreBuildingZone = { Polygon = polygon.createRectangle( {4, 4} ) } 
else
    Henhouse:log("Hello World: game version " .. foundation.getGameVersion())
    myMonument.AssetCoreBuildingPart = _PastryPrefix .. "_HENHOUSE_PART"
    _vjrTagBehaviorWork = "BEHAVIOR_WORK"

    _CoreBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( {4, 4} ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } }
    }}
end

Henhouse:register(myMonument)

Henhouse:dofile("scripts/compHenHouse.lua")

-- Register prefab nodes (currently only one core model)
Henhouse:registerAssetId("models/henhouse.fbx/Prefab/henhousePart", _PastryPrefix .. "_HENHOUSE_PREFAB")

-- Register the henhouse workplace part
Henhouse:register({
	DataType = "BUILDING_PART",
	Id = _PastryPrefix .. "_HENHOUSE_PART",
        BuildingZone = _CoreBuildingZone,
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = _PastryPrefix .. "_HENHOUSE_PREFAB"
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "WOOD", Quantity = 5 }
		}
	},
	AssetBuildingFunction = "FUNCTION_" .. _PastryPrefix .. "_HENHOUSE"
})

Henhouse:register({
		DataType = "BUILDING_FUNCTION_WORKPLACE",
                Id = "FUNCTION_" .. _PastryPrefix .. "_HENHOUSE",
		WorkerCapacity = 1,
                RelatedJob = { Job = _PastryPrefix .. "_HEN_BREEDER", Behavior = _vjrTagBehaviorWork },
                InputInventoryCapacity = {
			{ Resource = "WHEAT", Quantity = 2 }
                },
                ResourceListNeeded = {
                	{ Resource = "WHEAT", Quantity = 1 }
                },
                ResourceProduced = {
			{ Resource = _CommonEgg, Quantity = 4 }
                }
})

-- Register grass clearing components

Henhouse:registerPrefabComponent("models/henhouse.fbx/Prefab/henhousePart", {
	DataType = "COMP_DIRT_RECTANGLE",
	Size = {5, 5}
})

Henhouse:registerPrefabComponent("models/henhouse.fbx/Prefab/henhousePart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 4, 4 }
})

Henhouse:registerAssetId("models/henhouse.fbx/Prefab/henhousePart/step_1/door", _PastryPrefix .. "_HENHOUSE_DOOR_PREFAB")

Henhouse:registerPrefabComponent("models/henhouse.fbx/Prefab/henhousePart", {
	DataType = "COMP_BUILDING_PART",
	FeedbackComponentListToActivate = {
		{ _PastryPrefix .. "_HENHOUSE_DOOR_PREFAB", _PastryPrefix .. "_HENHOUSE_DOOR_COMP" }
	}
})

Henhouse:registerPrefabComponent("models/henhouse.fbx/Prefab/henhousePart/step_1/door", {
	DataType = _PastryPrefix .. "_HENHOUSE_DOOR_COMP",
	Enabled = false
})
Henhouse:registerPrefabComponent("models/henhouse.fbx/Prefab/henhousePart/step_1/door", {
	DataType = "COMP_GROUNDED"
})

--------------------------------------------------------------------------
function registerHen(_henNumber)
    Henhouse:registerPrefabComponent("models/henhouse.fbx/Prefab/henhousePart/poule" .. _henNumber .. "/groupMove" .. _henNumber, {
	DataType = _PastryPrefix .. "_HENHOUSE_COMP",
	Enabled = true
    })
    Henhouse:registerPrefabComponent("models/henhouse.fbx/Prefab/henhousePart/poule" .. _henNumber, {
	DataType = "COMP_GROUNDED"
    })
end

registerHen(1)
registerHen(2)
registerHen(3)
